@@ -18,5 +18,5 @@ def has_access(f):
                     return f(self, *args, **kwargs)
                 else:
                     flash("Access is Denied %s %s" % (f.__name__, self.__class__.__name__),"danger")
-            return redirect(url_for("AuthView.login"))
+            return redirect(url_for(self.baseapp.sm.auth_view.__class__.__name__+ ".login"))
         return wraps
